@@ -1,6 +1,6 @@
-//$Id: app-res.cc,v 1.24 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: app-res.cc,v 1.26 2005/10/08 16:16:09 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -59,3 +59,31 @@ void Resources::Application::reset ()
 
     changed ();
 }
+
+void Resources::Application::set_tag (const tag_key_t &key,
+                                      const tag_val_t &val)
+{
+    tags[key] = val;
+}
+
+Resources::Application::tag_val_t Resources::Application::get_tag (const tag_key_t &key) const
+{
+    tag_map_t::const_iterator i = tags.find (key);
+    
+    if (i == tags.end ())
+        return "";
+    else
+        return i->second;
+}
+
+Resources::Application::tag_map_t Resources::Application::get_tags () const
+{
+    return tags;
+}
+
+void Resources::Application::add_tags (const tag_map_t &new_tags)
+{
+    for (tag_map_t::const_iterator i = new_tags.begin (); i != new_tags.end (); ++i)
+        if (i->first != "" && i->second != "")
+            tags[i->first] = i->second;
+}
