@@ -1,6 +1,6 @@
-//$Id: app-res.h,v 1.23 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: app-res.h,v 1.25 2005/10/08 16:16:09 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -21,6 +21,7 @@
 
 #include "property.h"
 #include "queued-signal.h"
+#include <map>
 
 namespace Guikachu
 {
@@ -41,7 +42,14 @@ namespace Guikachu
 		inline const std::string& operator= (const std::string &value_) { set_val (value_); return value; };
 		virtual void set_val (const std::string &value);
 	    };
-	    
+
+        public:
+            typedef std::string tag_key_t;
+            typedef std::string tag_val_t;
+            typedef std::map<tag_key_t, tag_val_t> tag_map_t;
+        private:
+            tag_map_t tags;
+            
 	public:
 	    Application (ResourceManager *manager);
 	    QueuedSignal changed;
@@ -53,6 +61,11 @@ namespace Guikachu
 	    VendorID              vendor;
 	    
 	    void reset ();
+
+            void set_tag (const tag_key_t &key, const tag_val_t &val);
+            tag_val_t get_tag (const tag_key_t &key) const;
+            tag_map_t get_tags () const;
+            void add_tags (const tag_map_t &tags);
 	};
     };
 };
