@@ -1,6 +1,6 @@
-//$Id: bitmap-win.h,v 1.6 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: bitmap-win.h,v 1.8 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -23,8 +23,8 @@
 #include "resource-win.h"
 
 #include <gtkmm/window.h>
-#include <gtkmm/optionmenu.h>
 #include <gtkmm/image.h>
+#include <gtkmm/button.h>
 
 namespace Guikachu
 {
@@ -35,11 +35,9 @@ namespace Guikachu
 	{
 	    Resources::Bitmap *res;
 	    
-	    Gtk::Window        window;	    
-	    Gtk::OptionMenu    type_combo;
-            Gtk::Image         preview_pixmap;
-
-            Gtk::Button       *export_button;
+	    Gtk::Window  window;	    
+            Gtk::Image   preview_pixmap;
+            Gtk::Button *export_button;
 
 	public:
 	    BitmapWindow (Resources::Bitmap *res);
@@ -50,9 +48,6 @@ namespace Guikachu
 	    void update ();
             void update_image ();
 
-	    void type_menu_cb (Resources::Bitmap::BitmapType type);
-	    bool update_block;
-
             void load_image_cb ();
 	    void export_image_cb ();
 	};
