@@ -1,6 +1,6 @@
-//$Id: blob-win.h,v 1.6 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: blob-win.h,v 1.8 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -29,7 +29,7 @@ namespace Guikachu
     namespace GUI
     {
 	class BlobWindow: public ResourceWindow,
-			  public SigC::Object
+			  public sigc::trackable
 	{
 	    Resources::Blob *res;
 	    Gtk::Window      window;
