@@ -1,4 +1,4 @@
-//$Id: edit-cut-and-paste.h,v 1.8 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: edit-cut-and-paste.h,v 1.10 2005/10/17 13:52:18 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,19 +25,19 @@
 
 #include <set>
 
-#include <gtk/gtkselection.h>
-#include <gtkmm/widget.h>
-
 namespace Guikachu
 {
     namespace Edit
     {
-	void copy_resource (Resource *resource);
-	void paste_resources (ResourceManager *manager);
+	void copy_resource      (Resource *resource);
+        void duplicate_resource (Resource *resource);
+	void paste_resources    (ResourceManager *manager);
 
-	void copy_widget   (Widget *widget);
-	void copy_widgets  (const std::set<Widget*> &widgets);
-	void paste_widgets (Resources::Form *form);
+	void copy_widget       (Widget *widget);
+	void copy_widgets      (const std::set<Widget*> &widgets);
+	void duplicate_widget  (Widget *widget);
+	void duplicate_widgets (const std::set<Widget*> &widgets);
+	void paste_widgets     (Resources::Form *form);
     }
 }
 
