@@ -1,4 +1,4 @@
-//$Id: button-canvas.cc,v 1.37 2005/07/29 09:54:15 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.cc,v 1.38 2005/11/04 19:35:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -56,53 +56,53 @@ void ButtonCanvasItem::create_simple_border (FooCanvasmm::Group &group) const
 
     memset (pixdata, 0, pix_height * rowstride);
     
-#define _GUIKACHU_OFFSET(x,y)				\
+#define GUIKACHU_OFFSET(x,y)				\
     (MIN (MAX (0, (y)), (pix_height - 1)) * rowstride +	\
      MIN (MAX (0, (x)), (pix_width - 1)) * 4)
 
-#define _GUIKACHU_PLOT(x,y)						\
+#define GUIKACHU_PLOT(x,y)						\
     {									\
-	pixdata[_GUIKACHU_OFFSET(x,y) + 0] = color.get_red ()   >> 8;	\
-	pixdata[_GUIKACHU_OFFSET(x,y) + 1] = color.get_green () >> 8;	\
-	pixdata[_GUIKACHU_OFFSET(x,y) + 2] = color.get_blue ()  >> 8;	\
-	pixdata[_GUIKACHU_OFFSET(x,y) + 3] = 255;			\
+	pixdata[GUIKACHU_OFFSET(x,y) + 0] = color.get_red ()   >> 8;	\
+	pixdata[GUIKACHU_OFFSET(x,y) + 1] = color.get_green () >> 8;	\
+	pixdata[GUIKACHU_OFFSET(x,y) + 2] = color.get_blue ()  >> 8;	\
+	pixdata[GUIKACHU_OFFSET(x,y) + 3] = 255;			\
     }
 
     // N and S border
     for (int x = 3; x < width - 1; x++)
     {
-	_GUIKACHU_PLOT (x, 0);
-	_GUIKACHU_PLOT (x, height);
+	GUIKACHU_PLOT (x, 0);
+	GUIKACHU_PLOT (x, height);
     }
     
     // W and E border
     for (int y = 3; y < height - 2; y++)
     {
-	_GUIKACHU_PLOT (0, y);
-	_GUIKACHU_PLOT (width + 1, y);
+	GUIKACHU_PLOT (0, y);
+	GUIKACHU_PLOT (width + 1, y);
     }
 
     // NW corner
-    _GUIKACHU_PLOT (1, 1);
-    _GUIKACHU_PLOT (2, 1);
-    _GUIKACHU_PLOT (1, 2);
+    GUIKACHU_PLOT (1, 1);
+    GUIKACHU_PLOT (2, 1);
+    GUIKACHU_PLOT (1, 2);
 
     // NE corner
-    _GUIKACHU_PLOT (width, 1);
-    _GUIKACHU_PLOT (width - 1, 1);
-    _GUIKACHU_PLOT (width, 2);
+    GUIKACHU_PLOT (width, 1);
+    GUIKACHU_PLOT (width - 1, 1);
+    GUIKACHU_PLOT (width, 2);
 
     // SE corner
-    _GUIKACHU_PLOT (width - 1, height - 1);
-    _GUIKACHU_PLOT (width, height - 1);
-    _GUIKACHU_PLOT (width, height - 2);
+    GUIKACHU_PLOT (width - 1, height - 1);
+    GUIKACHU_PLOT (width, height - 1);
+    GUIKACHU_PLOT (width, height - 2);
 
     // SW corner
-    _GUIKACHU_PLOT (1, height - 1);
-    _GUIKACHU_PLOT (2, height - 1);
-    _GUIKACHU_PLOT (1, height - 2);
+    GUIKACHU_PLOT (1, height - 1);
+    GUIKACHU_PLOT (2, height - 1);
+    GUIKACHU_PLOT (1, height - 2);
 
-#undef _GUIKACHU_PLOT
+#undef GUIKACHU_PLOT
     
     FooCanvasmm::Pixbuf *pixbuf_item = new FooCanvasmm::Pixbuf (group, x1 - 1, y1 - 1, pixbuf);
     pixbuf_item->property_interp_type () = Gdk::INTERP_NEAREST;
@@ -132,32 +132,32 @@ void ButtonCanvasItem::create_bold_border (FooCanvasmm::Group &group) const
 
     memset (pixdata, 0, pix_height * rowstride);
 
-#define _GUIKACHU_PLOT(x,y)						\
+#define GUIKACHU_PLOT(x,y)						\
     {									\
-	pixdata[_GUIKACHU_OFFSET(x, y) + 0] = color.get_red ()   >> 8;	\
-	pixdata[_GUIKACHU_OFFSET(x, y) + 1] = color.get_green () >> 8;	\
-	pixdata[_GUIKACHU_OFFSET(x, y) + 2] = color.get_blue ()  >> 8;	\
-	pixdata[_GUIKACHU_OFFSET(x, y) + 3] = 255;			\
+	pixdata[GUIKACHU_OFFSET(x, y) + 0] = color.get_red ()   >> 8;	\
+	pixdata[GUIKACHU_OFFSET(x, y) + 1] = color.get_green () >> 8;	\
+	pixdata[GUIKACHU_OFFSET(x, y) + 2] = color.get_blue ()  >> 8;	\
+	pixdata[GUIKACHU_OFFSET(x, y) + 3] = 255;			\
     }
 
     // N and S border
     for (int x = 6; x < width - 2; x++)
     {
-	_GUIKACHU_PLOT (x, 0);
-	_GUIKACHU_PLOT (x, 1);
+	GUIKACHU_PLOT (x, 0);
+	GUIKACHU_PLOT (x, 1);
 	
-	_GUIKACHU_PLOT (x, height + 2);
-	_GUIKACHU_PLOT (x, height + 3);
+	GUIKACHU_PLOT (x, height + 2);
+	GUIKACHU_PLOT (x, height + 3);
     }
 
     // W and E border
     for (int y = 5; y < height - 1; y++)
     {
-	_GUIKACHU_PLOT (0, y);
-	_GUIKACHU_PLOT (1, y);
+	GUIKACHU_PLOT (0, y);
+	GUIKACHU_PLOT (1, y);
 	
-	_GUIKACHU_PLOT (width + 2, y);
-	_GUIKACHU_PLOT (width + 3, y);
+	GUIKACHU_PLOT (width + 2, y);
+	GUIKACHU_PLOT (width + 3, y);
     }
 
     // NW corner
@@ -199,16 +199,16 @@ void ButtonCanvasItem::create_bold_border (FooCanvasmm::Group &group) const
 	for (int parse_x = 0; parse_x < corner_width; parse_x++)
 	{
 	    if (corner_nw[parse_y][parse_x] != ' ')
-		_GUIKACHU_PLOT (1 + parse_x, parse_y);
+		GUIKACHU_PLOT (1 + parse_x, parse_y);
 	    if (corner_ne[parse_y][parse_x] != ' ')
-		_GUIKACHU_PLOT (width - 2 + parse_x, parse_y);
+		GUIKACHU_PLOT (width - 2 + parse_x, parse_y);
 	    if (corner_se[parse_y][parse_x] != ' ')
-		_GUIKACHU_PLOT (width - 2 + parse_x, height - 2 + parse_y);
+		GUIKACHU_PLOT (width - 2 + parse_x, height - 2 + parse_y);
 	    if (corner_sw[parse_y][parse_x] != ' ')
-		_GUIKACHU_PLOT (1 + parse_x, height - 2 + parse_y);
+		GUIKACHU_PLOT (1 + parse_x, height - 2 + parse_y);
 	}
     
-#undef _GUIKACHU_PLOT
+#undef GUIKACHU_PLOT
     
     FooCanvasmm::Pixbuf *pixbuf_item = new FooCanvasmm::Pixbuf (group, x1 - 2, y1 - 2, pixbuf);
     pixbuf_item->property_interp_type () = Gdk::INTERP_NEAREST;
