@@ -1,6 +1,6 @@
-//$Id: selector-trigger.h,v 1.23 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.h,v 1.25 2005/07/29 09:54:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -21,6 +21,8 @@
 
 #include "widget.h"
 #include "auto-resizeable.h"
+#include "usable.h"
+#include "disabled.h"
 #include "textual.h"
 #include "graphical.h"
 
@@ -31,6 +33,8 @@ namespace Guikachu
 	class SelectorTrigger: public Widget,
 			       public AutoWidth,
 			       public AutoHeight,
+                               public Usable,
+                               public Disabled,
 			       public Textual,
                                public Graphical
 	{
@@ -40,7 +44,6 @@ namespace Guikachu
 	    Type get_type () const { return WIDGET_SELECTOR_TRIGGER; };
 	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
 	    
-	    Property<bool> usable;
 	    Property<bool> anchor_right;
 
 	protected:
