@@ -1,6 +1,6 @@
-//$Id: text-field-canvas.h,v 1.9 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: text-field-canvas.h,v 1.11 2005/07/29 09:54:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -33,12 +33,13 @@ namespace Guikachu
 				       public ResizeableCanvasItem
 	    {
 		Widgets::TextField *widget;
-		FooCanvasmm::Group *group;
+
 	    public:
 		TextFieldCanvasItem (Widgets::TextField *widget,
 				     FooCanvasmm::Group &parent_group);
+
 	    protected:
-		virtual void update ();
+		virtual void draw (FooCanvasmm::Group &group) const;
 		virtual void get_bounds (int &x1, int &y1,
 					 int &x2, int &y2);
 	    };
