@@ -1,6 +1,6 @@
-//$Id: textual-prop.cc,v 1.12 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: textual-prop.cc,v 1.14 2005/07/29 09:54:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -36,7 +36,7 @@ void TextualProperties::add_controls (Widgets::Textual   *res,
     /* Label */
     control = new GUI::PropertyEditors::Entry (
 	true, res->text, new WidgetOps::PropChangeOpFactory<std::string> (
-	    _("Change label of %s"), dynamic_cast<Widget*>(res), res->text, true));
+	    _("Change text of %s"), dynamic_cast<Widget*>(res), res->text, true));
     proptable.add (_("_Text:"), *manage (control));
 
     /* Font */
