@@ -1,6 +1,6 @@
-//$Id: widget-factory.h,v 1.2 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
+//$Id: widget-factory.h,v 1.5 2005/07/29 09:54:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -21,6 +21,7 @@
 
 #include "form-editor/widget.h"
 #include "form-editor/widget-canvas.h"
+#include <gtkmm/widget.h>
 
 namespace Guikachu
 {
@@ -28,7 +29,7 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    WidgetCanvasItem * get_widget_canvas_item (Widget *widget, Gnome::CanvasGroup *group);
+	    WidgetCanvasItem * get_widget_canvas_item (Widget *widget, FooCanvasmm::Group &group);
 	    Gtk::Widget *      get_widget_editor (Widget *widget);
 	}
     }
