@@ -1,6 +1,6 @@
-//$Id: widget.h,v 1.45 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: widget.h,v 1.48 2005/07/29 09:54:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -35,6 +35,7 @@ namespace Guikachu
 	    WIDGET_LIST,
 	    WIDGET_POPUP_TRIGGER,
 	    WIDGET_SCROLLBAR,
+	    WIDGET_SLIDER,
 	    WIDGET_TEXT_FIELD,
 	    WIDGET_TABLE,
             WIDGET_FORMBITMAP,
@@ -72,6 +73,8 @@ namespace Guikachu
 		serial_t           serial);
 	
     public:
+        typedef Widgets::Type type_t;
+        
 	virtual ~Widget ();
 	
 	virtual Widgets::Type get_type () const = 0;
