@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.74 2005/11/04 19:35:45 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.75 2005/11/10 20:13:10 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,10 +32,9 @@
 #include <foocanvasmm/polygon.h>
 #include "form-editor/screen-canvas.h"
 
-#include <libgnomeuimm/app-helper.h>
-#include <libgnomeuimm/ui-items-stock.h>
-#include <libgnomeuimm/app-helper.h>
+#include <gtkmm/uimanager.h>
 #include <gtkmm/stock.h>
+#include "stock.h"
 
 #include <sigc++/adaptors/bind.h>
 #include <sigc++/adaptors/bind_return.h>
@@ -47,13 +46,6 @@
 #include "target.h"
 #include "form-editor/widget-ops.h"
 
-#include "pixmaps/menu-align-left.xpm"
-#include "pixmaps/menu-align-right.xpm"
-#include "pixmaps/menu-align-top.xpm"
-#include "pixmaps/menu-align-bottom.xpm"
-#include "pixmaps/menu-center-horizontal.xpm"
-#include "pixmaps/menu-center-vertical.xpm"
-
 #include "form-editor/widget-factory.h"
 
 using namespace Guikachu::GUI;
@@ -68,8 +60,6 @@ FormWindow::FormWindow (Form *res_):
     gui (Gnome::Glade::Xml::create (GUIKACHU_GLADEDIR "/guikachu.glade", "res_form")),
     edited_widget (0),
     last_widget (0),
-    form_popup_menu (0),
-    widget_popup_menu (0),
     canvas_overlay (0),
     palette_selection (Widgets::WIDGET_NONE)
 {
@@ -150,9 +140,6 @@ FormWindow::FormWindow (Form *res_):
 
 FormWindow::~FormWindow ()
 {
-    delete form_popup_menu;
-    delete widget_popup_menu;
-    
     delete form_widget;
     delete property_window;
     delete widget_tree;
@@ -382,38 +369,50 @@ void FormWindow::form_released_cb ()
     selection_canvas->set_active (true);
 }
 
+#define GN_(s) dgettext ("libgnomeui-2.0", (s))
+
 void FormWindow::form_menu_cb (guint   button,
 			       guint32 time)
 {
-    // Create popup menu
-    if (form_popup_menu)
-	delete form_popup_menu;
+    Glib::RefPtr<Gtk::UIManager> uimanager = Gtk::UIManager::create ();
+    Glib::RefPtr<Gtk::ActionGroup> group = Gtk::ActionGroup::create ();
     
-    form_popup_menu = new Gtk::Menu;
+    group->add (Gtk::Action::create ("edit_form", Gtk::Stock::PROPERTIES, _("_Edit Form")),
+                sigc::mem_fun (*this, &FormWindow::select_form));
+    group->add (Gtk::Action::create ("select_all", _("_Select All")),
+                sigc::mem_fun (*this, &FormWindow::select_all));
+    group->add (Gtk::Action::create ("cut", Gtk::Stock::CUT),
+                sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_cut_cb), (Widget*)0));
+    group->add (Gtk::Action::create ("copy", Gtk::Stock::COPY),
+                sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_copy_cb), (Widget*)0));
+    group->add (Gtk::Action::create ("paste", Gtk::Stock::PASTE),
+                sigc::mem_fun (*this, &FormWindow::widget_paste_cb));
 
-    Gnome::UI::Items::Info popup_menu_list[] = {
-	Gnome::UI::Items::Item      (Gnome::UI::Items::Icon (Gtk::Stock::PROPERTIES),
-				     _("_Edit form"),
-				     sigc::mem_fun (*this, &FormWindow::select_form)),
-	Gnome::UI::Items::Item      (_("_Select all"),
-				     sigc::mem_fun (*this, &FormWindow::select_all)),
-	Gnome::UI::Items::Separator (),
-	Gnome::UI::MenuItems::Cut   (sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_cut_cb), (Widget*)0)),
-	Gnome::UI::MenuItems::Copy  (sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_copy_cb), (Widget*)0)),
-	Gnome::UI::MenuItems::Paste (sigc::mem_fun (*this, &FormWindow::widget_paste_cb))
-    };
-
-    Gnome::UI::Items::Array<Gnome::UI::Items::Info> popup_menu_widgets =
-	Gnome::UI::Items::fill (*form_popup_menu, popup_menu_list,
-				form_popup_menu->get_accel_group ());
+    static const char *ui_description =
+        "<ui>"
+        "  <popup>"
+        "    <menuitem action='edit_form'/>"
+        "    <menuitem action='select_all'/>"
+        "    <separator/>"        
+        "    <menuitem action='cut'/>"
+        "    <menuitem action='copy'/>"
+        "    <menuitem action='paste'/>"
+        "  </popup>"
+        "</ui>";
     
     if (!selection.size ())
     {
-	popup_menu_widgets[3].get_widget ()->set_sensitive (false); // Cut
-	popup_menu_widgets[4].get_widget ()->set_sensitive (false); // Copy
+        group->get_action ("cut")->set_sensitive (false);
+        group->get_action ("copy")->set_sensitive (false);
     }
     
-    form_popup_menu->popup (button, time);
+    uimanager->insert_action_group (group);
+    uimanager->add_ui_from_string (ui_description);
+    
+    Gtk::Widget *popup_menu_widget = uimanager->get_widget ("/popup");
+    Gtk::Menu   *popup_menu = dynamic_cast<Gtk::Menu*> (popup_menu_widget);
+
+    popup_menu->popup (button, time);
 }
 
 void FormWindow::widget_clicked_cb (Widget *widget)
@@ -436,64 +435,78 @@ void FormWindow::widget_menu_cb (guint    button,
 {
     if (selection.find (widget) == selection.end ())
 	select_widget (widget);
-    
-    // Create popup menu
-    if (widget_popup_menu)
-	delete widget_popup_menu;
-    
-    widget_popup_menu = new Gtk::Menu;
-    std::list <Gnome::UI::Items::Info> popup_menu_list;
-    popup_menu_list.push_back (
-	Gnome::UI::Items::Item (Gnome::UI::Items::Icon (Gtk::Stock::PROPERTIES),
-				_("_Edit"),
-				sigc::bind (sigc::mem_fun (*this, &FormWindow::select_widget), widget)));
-    popup_menu_list.push_back (Gnome::UI::Items::Separator ());
-    popup_menu_list.push_back (Gnome::UI::MenuItems::Cut (
-	sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_cut_cb), widget)));
-    popup_menu_list.push_back (Gnome::UI::MenuItems::Copy (
-	sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_copy_cb), widget)));
-    popup_menu_list.push_back (Gnome::UI::MenuItems::Paste (
-	sigc::mem_fun (*this, &FormWindow::widget_paste_cb)));
-    popup_menu_list.push_back (Gnome::UI::Items::Separator ());
-    popup_menu_list.push_back (
-	Gnome::UI::Items::Item (_("_Duplicate"),
-				sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_duplicate_cb), widget)));
-    
-    popup_menu_list.push_back (
-	Gnome::UI::Items::Item (Gnome::UI::Items::Icon (Gtk::Stock::DELETE),
-				_("_Remove"),
-				sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_remove_cb), widget)));
 
-    popup_menu_list.push_back (Gnome::UI::Items::Separator ());
-    popup_menu_list.push_back (Gnome::UI::Items::Item (
-                                   Gnome::UI::Items::IconXpm (menu_center_horizontal_xpm),
-                                   _("Center _horizontally"), sigc::mem_fun (*this, &FormWindow::center_horizontal)));
-    popup_menu_list.push_back (Gnome::UI::Items::Item (
-                                   Gnome::UI::Items::IconXpm (menu_center_vertical_xpm),
-                                   _("Center _vertically"), sigc::mem_fun (*this, &FormWindow::center_vertical)));
+    Glib::RefPtr<Gtk::UIManager> uimanager = Gtk::UIManager::create ();
+    Glib::RefPtr<Gtk::ActionGroup> group = Gtk::ActionGroup::create ();
     
+    group->add (Gtk::Action::create ("edit", Gtk::Stock::PROPERTIES, _("_Edit Form")),
+                sigc::bind (sigc::mem_fun (*this, &FormWindow::select_widget), widget));
+    group->add (Gtk::Action::create ("select_all", _("_Select All")),
+                sigc::mem_fun (*this, &FormWindow::select_all));
+    
+    group->add (Gtk::Action::create ("cut", Gtk::Stock::CUT),
+                sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_cut_cb), widget));
+    group->add (Gtk::Action::create ("copy", Gtk::Stock::COPY),
+                sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_copy_cb), widget));
+    group->add (Gtk::Action::create ("paste", Gtk::Stock::PASTE),
+                sigc::mem_fun (*this, &FormWindow::widget_paste_cb));
+    
+    group->add (Gtk::Action::create ("duplicate", _("_Duplicate")),
+                sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_duplicate_cb), widget));
+    group->add (Gtk::Action::create ("remove", Gtk::Stock::DELETE),
+                sigc::bind (sigc::mem_fun (*this, &FormWindow::widget_remove_cb), widget));
+
+    group->add (Gtk::Action::create ("center-horiz", GUI::Stock::CENTER_HORIZ),
+                sigc::mem_fun (*this, &FormWindow::center_horizontal));
+    group->add (Gtk::Action::create ("center-vert", GUI::Stock::CENTER_VERT),
+                sigc::mem_fun (*this, &FormWindow::center_vertical));
+
+    group->add (Gtk::Action::create ("align-left", GUI::Stock::ALIGN_LEFT),
+                sigc::mem_fun (*this, &FormWindow::align_left));
+    group->add (Gtk::Action::create ("align-right", GUI::Stock::ALIGN_RIGHT),
+                sigc::mem_fun (*this, &FormWindow::align_right));
+    group->add (Gtk::Action::create ("align-top", GUI::Stock::ALIGN_TOP),
+                sigc::mem_fun (*this, &FormWindow::align_top));
+    group->add (Gtk::Action::create ("align-bottom", GUI::Stock::ALIGN_BOTTOM),
+                sigc::mem_fun (*this, &FormWindow::align_bottom));
+    
+    static const char *ui_description =
+        "<popup>"
+        "  <menuitem action='edit'/>"
+        "  <menuitem action='select_all'/>"
+        "  <separator/>"        
+        "  <menuitem action='cut'/>"
+        "  <menuitem action='copy'/>"
+        "  <menuitem action='paste'/>"
+        "  <separator/>"        
+        "  <menuitem action='duplicate'/>"
+        "  <menuitem action='remove'/>"
+        "  <separator/>"        
+        "  <menuitem action='center-horiz'/>"
+        "  <menuitem action='center-vert'/>"
+        "  <separator/>"
+        "  <placeholder name='align'/>"
+        "</popup>";
+
+    static const char *align_description =
+        "<popup>"
+        "  <placeholder name='align'>"
+        "    <menuitem action='align-left'/>"
+        "    <menuitem action='align-right'/>"
+        "    <menuitem action='align-top'/>"
+        "    <menuitem action='align-bottom'/>"
+        "  </placeholder>"
+        "</popup>";
+    
+    uimanager->insert_action_group (group);
+    uimanager->add_ui_from_string (ui_description);
     if (selection.size () > 1 && selection.find (widget) != selection.end ())
-    {
-	popup_menu_list.push_back (Gnome::UI::Items::Separator ());
-	
-	popup_menu_list.push_back (Gnome::UI::Items::Item (
-	    Gnome::UI::Items::IconXpm (menu_align_left_xpm),
-	    _("Align to _left"), sigc::mem_fun (*this, &FormWindow::align_left)));
-	popup_menu_list.push_back (Gnome::UI::Items::Item (
-	    Gnome::UI::Items::IconXpm (menu_align_right_xpm),
-	    _("Align to ri_ght"), sigc::mem_fun (*this, &FormWindow::align_right)));
-	popup_menu_list.push_back (Gnome::UI::Items::Item (
-	    Gnome::UI::Items::IconXpm (menu_align_top_xpm),
-	    _("Align to _top"), sigc::mem_fun (*this, &FormWindow::align_top)));
-	popup_menu_list.push_back (Gnome::UI::Items::Item (
-	    Gnome::UI::Items::IconXpm (menu_align_bottom_xpm),
-	    _("Align to _bottom"), sigc::mem_fun (*this, &FormWindow::align_bottom)));
-    }
+        uimanager->add_ui_from_string (align_description);
     
-    Gnome::UI::Items::fill (*widget_popup_menu, popup_menu_list,
-			    widget_popup_menu->get_accel_group ());
-    
-    widget_popup_menu->popup (button, time);
+    Gtk::Widget *popup_menu_widget = uimanager->get_widget ("/popup");
+    Gtk::Menu   *popup_menu = dynamic_cast<Gtk::Menu*> (popup_menu_widget);
+
+    popup_menu->popup (button, time);
 }
 
 void FormWindow::widget_remove_cb (Widget *widget)
