@@ -1,6 +1,6 @@
-//$Id: io.h,v 1.11 2004/09/05 12:43:02 cactus Exp $ -*- c++ -*-
+//$Id: io.h,v 1.14 2005/07/29 09:54:17 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -31,9 +31,11 @@ namespace Guikachu
 	Glib::ustring create_canonical_uri (const Glib::ustring &filename);
         Glib::ustring get_mime_type (const Glib::ustring &uri) throw (Glib::Exception);
         
-	void load_uri (const Glib::ustring &uri, char *&data, Gnome::Vfs::FileSize &len) throw (Glib::Exception);
-	void save_uri (const Glib::ustring &uri, const char *data, Gnome::Vfs::FileSize len) throw (Glib::Exception);
-        
+	void load_uri (const Glib::ustring &uri, unsigned char *&data, Gnome::Vfs::FileSize &len) throw (Glib::Exception);
+	void save_uri (const Glib::ustring &uri, const unsigned char *data, Gnome::Vfs::FileSize len) throw (Glib::Exception);
+
+	bool uri_exists (const Glib::ustring &uri);
+	
 	class Loader
 	{
 	public:
