@@ -1,4 +1,4 @@
-//$Id: mainwin-edit.cc,v 1.6 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-edit.cc,v 1.7 2005/10/15 09:52:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -51,3 +51,13 @@ void MainWin::paste_cb ()
 {
     Edit::paste_resources (manager);
 }
+
+void MainWin::duplicate_cb ()
+{
+    Resource *selected_resource = resource_tree.get_selected ();
+    if (!selected_resource)
+	return;
+
+    Edit::duplicate_resource (selected_resource);
+}
+
