@@ -1,4 +1,4 @@
-//$Id: mainwin-io.cc,v 1.42 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.43 2005/11/05 11:24:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -191,7 +191,7 @@ void GUI::MainWin::save_as_cb ()
     
 void GUI::MainWin::load_cb ()
 {
-    Gtk::FileChooserDialog file_chooser (*this, _("Select a Guikachu to open"), Gtk::FILE_CHOOSER_ACTION_OPEN);
+    Gtk::FileChooserDialog file_chooser (*this, _("Select a Guikachu file to open"), Gtk::FILE_CHOOSER_ACTION_OPEN);
     file_chooser.add_button (Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
     file_chooser.add_button (Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT);
     file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);
