@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.51 2005/11/05 11:53:04 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.52 2005/11/10 21:43:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -35,9 +35,6 @@
 
 #include "cellrenderer-indent.h"
 
-#include <libgnomeuimm/app-helper.h>
-#include <libgnomeuimm/ui-items-stock.h>
-#include <libgnomeuimm/app-helper.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/box.h>
 
