@@ -1,4 +1,4 @@
-//$Id: session.cc,v 1.30 2005/10/01 10:36:17 cactus Exp $ -*- c++ -*-
+//$Id: session.cc,v 1.32 2005/11/15 20:34:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,6 +31,7 @@
 #include "resource-manager.h"
 #include "mainwin.h"
 #include "ui.h"
+#include "stock.h"
 #include "preferences.h"
 
 #include "io/xml-loader.h"
@@ -48,6 +49,10 @@ namespace {
     }   
 } // anonymous namespace
 
+namespace {
+#include "pixmaps/inline-pixbufs.h"
+}
+
 Main* Guikachu::Main::instance_ = 0;
 
 Main::Main (int argc, char **argv):
@@ -81,6 +86,10 @@ Main::Main (int argc, char **argv):
 	    cmd_arguments.push_back (*args);
     poptFreeContext (ctx);
 
+    UI::register_stock ();
+    static Glib::RefPtr<Gdk::Pixbuf> icon = Gdk::Pixbuf::create_from_inline (-1, guikachu_icon_gdkbuf);
+    Gtk::Window::set_default_icon (icon);
+    
     // Init preferences
     Preferences::init ();
 
