@@ -1,4 +1,4 @@
-//$Id: storage.h,v 1.18 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: storage.h,v 1.20 2005/11/02 12:33:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -43,6 +43,8 @@ namespace Guikachu
 	void load        (const Glib::ustring &filename) throw (Glib::Exception); 
 	void load_uri    (const Glib::ustring &uri) throw (Glib::Exception);
 	void save_uri    (const Glib::ustring &uri) const throw (Glib::Exception);
+
+        void load_buffer (unsigned char *buffer, Gnome::Vfs::FileSize buffer_size) throw (Glib::Exception);
 	void save_buffer (unsigned char *&buffer, Gnome::Vfs::FileSize &buffer_size) const;
 	
 	StorageNode get_root    ();
@@ -50,6 +52,9 @@ namespace Guikachu
 	StorageNode create_root (const std::string &name);
 
 	sigc::signal0<void> encoding_notify;
+
+    private:
+        void clear ();
     };
     
 }; // namespace Guikachu
