@@ -1,4 +1,4 @@
-//$Id: ui-gui.cc,v 1.12 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: ui-gui.cc,v 1.15 2005/11/05 08:20:22 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,7 +28,7 @@
 #include <gtkmm/image.h>
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/main.h>
-#include <libgnomeuimm/about.h>
+#include <gtkmm/aboutdialog.h>
 
 #include <list>
 #include <iostream>
@@ -46,10 +46,17 @@ void UI::flush_events ()
 	    Gtk::Main::iteration ();
 }
 
-void UI::show_about ()
+namespace {
+    void about_uri_cb (Gtk::AboutDialog &about, const Glib::ustring &uri)
+    {
+        gnome_url_show (uri.c_str (), 0);
+    }
+} // anonymous namespace
+
+void UI::show_about (Gtk::Window *parent)
 {
     std::list<Glib::ustring> authors;
-    authors.push_back ("Gerg\xC5\x91 \xC3\x89rdi");
+    authors.push_back ("Gerg\xC5\x91 \xC3\x89rdi\thttp://cactus.rulez.org/");
     authors.push_back ("Jay Bloodworth");
     authors.push_back ("Christopher Keith Fairbairn");
     authors.push_back ("Tobias Gruetzmacher");
@@ -63,17 +70,43 @@ void UI::show_about ()
     Glib::ustring translators = _("translator_credits");
     if (translators == "translator_credits")
 	translators = "";
-    
-    static Gnome::UI::About *about = new Gnome::UI::About (
-	"Guikachu", VERSION,
-	"(C) 2001-2004 Gerg\xC5\x91 \xC3\x89rdi",
-	authors,
-	documenters,
-	_("PalmOS resource file editor"),
-	translators,
-        logo);
 
-    about->show ();
+    static const char *license =
+        "This program is free software; you can redistribute it and/or modify it\n"
+        "under the terms of the GNU General Public License version 2 as published\n"
+        "by the Free Software Foundation.\n"
+        "\n"
+        "This program is distributed in the hope that it will be useful but WITHOUT\n"
+        "ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n"
+        "or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public \n"
+        "License for more details.\n"
+        "\n"
+        "You should have received a copy of the GNU General Public License along\n"
+        "with this program; if not, write to the Free Software Foundation, Inc.,\n"
+        "59 Temple Place, Suite 330, Boston, MA 02111-1307 USA";
+    
+    Gtk::AboutDialog *about = new Gtk::AboutDialog;
+    about->set_url_hook (sigc::ptr_fun (about_uri_cb));
+
+    about->set_name ("Guikachu");
+    about->set_version (VERSION);
+    about->set_copyright ("Copyright \xC2\xA9 2001-2005 Gerg\xC5\x91 \xC3\x89rdi");
+    about->set_comments (_("PalmOS resource file editor"));
+    about->set_website ("http://cactus.rulez.org/projects/guikachu/");
+    about->set_website_label (_("Visit the Guikachu website"));
+
+    about->set_authors (authors);
+    //about->set_documenters (documenters);
+    if (translators != "")
+        about->set_translator_credits (translators);
+
+    about->set_logo (logo);
+    about->set_license (license);
+
+    if (parent)
+        about->set_transient_for (*parent);
+    about->run ();
+    delete about;
 }
 
 void UI::show_error (const Glib::ustring &full_message,
