@@ -1,6 +1,6 @@
-//$Id: target-combo.cc,v 1.11 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: target-combo.cc,v 1.13 2005/07/29 09:54:19 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -53,27 +53,31 @@ namespace Guikachu
 TargetCombo::TargetCombo (ResourceManager *manager_):
     PropertyEditor (this),
     manager (manager_),
-    target (manager->get_target ())
+    target (manager->get_target ()),
+    update_block (false)
 {
-    Gtk::Menu *target_menu = new Gtk::Menu;
-    Target::stock_list_t targets = Target::stock_targets ();
+    Gtk::TreeModel::ColumnRecord cols;
+    cols.add (col_id);
+    cols.add (col_label);
     
-    int current_index = 0;
-    for (Target::stock_list_t::const_iterator i = targets.begin ();
-	 i != targets.end (); ++i, ++current_index)
-    {
-	target_menu->items ().push_back (Gtk::Menu_Helpers::MenuElem (
-            i->second, sigc::bind (sigc::mem_fun (*this, &TargetCombo::target_stock_cb), i->first)));
-	
-	stock_target_to_menuitem[i->first] = current_index;
-    }
-    
-    target_menu->items ().push_back (Gtk::Menu_Helpers::MenuElem (
-        _("Custom machine"), sigc::mem_fun (*this, &TargetCombo::target_custom_cb)));
-    num_targets = current_index;
-    
-    set_menu (*manage (target_menu));
+    store = Gtk::ListStore::create (cols);
 
+    Target::stock_list_t targets = Target::stock_targets ();
+    for (Target::stock_list_t::const_iterator i = targets.begin (); i != targets.end (); ++i)
+    {
+        Gtk::TreeRow row = *(store->append ());
+        row[col_id] = i->first;
+        row[col_label] = i->second;
+    }
+
+    Gtk::TreeRow row = *(store->append ());
+    row[col_id] = "";
+    row[col_label] = _("Custom machine");
+
+    set_model (store);
+    pack_start (col_label);
+
+    signal_changed ().connect (sigc::mem_fun (*this, &TargetCombo::changed_cb));
     target->changed.connect (sigc::mem_fun (*this, &TargetCombo::update));
     update ();
 }
@@ -81,24 +85,34 @@ TargetCombo::TargetCombo (ResourceManager *manager_):
 void TargetCombo::update ()
 {
     Target::stock_id_t target_id = target->get_stock_id ();
-    if (target_id != "")
-	set_history (stock_target_to_menuitem[target_id]);
-    else
-	set_history (num_targets);
+
+    Gtk::TreeModel::iterator iter = store->get_iter ("0");
+    while (Target::stock_id_t ((*iter)[col_id]) != target_id)
+        ++iter;
+
+    update_block = true;
+    set_active (iter);
+    update_block = false;
 }
 
-void TargetCombo::target_stock_cb (Target::stock_id_t stock_id)
+void TargetCombo::changed_cb ()
 {
-    UndoOp *op = new TargetOps::StockOp (target, stock_id);
-    target->load_stock (stock_id);
-    manager->get_undo_manager ().push (op);
-    
-    stock_selected.emit ();
-}
+    if (update_block)
+        return;
 
-void TargetCombo::target_custom_cb ()
-{
-    custom_selected.emit ();
+    Gtk::TreeModel::iterator iter = get_active ();
+    Target::stock_id_t stock_id = (*iter)[col_id];
+
+    if (stock_id != "")
+    {
+        UndoOp *op = new TargetOps::StockOp (target, stock_id);
+        target->load_stock (stock_id);
+        manager->get_undo_manager ().push (op);
+        
+        stock_selected.emit ();
+    } else {
+        custom_selected.emit ();
+    }
 }
 
 Guikachu::TargetOps::StockOp::StockOp (Target            *target_,
