@@ -1,6 +1,6 @@
-//$Id: widget-combo.h,v 1.13 2004/07/19 13:51:51 cactus Exp $ -*- c++ -*-
+//$Id: widget-combo.h,v 1.15 2005/07/29 09:54:19 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -45,8 +45,8 @@ namespace Guikachu
     {
 	namespace PropertyEditors
 	{
-	    class WidgetCombo: public PropertyEditor,
-			       public Gtk::HBox
+	    class WidgetCombo: public Gtk::HBox,
+                               public PropertyEditor
 	    {
 		typedef Properties::WidgetRef            property_t;
 		typedef PropChangeOpFactory<std::string> op_factory_t;
